@@ -6,13 +6,15 @@ import logging
 import os
 import platform
 import random
+import sys
 import time
+from dataclasses import dataclass
 
 import coolname
 import prompt_toolkit
 import requests
 import rsa
-from dataclasses import dataclass
+import yaml
 from flask import Flask
 from flask_jwt_extended import create_access_token
 
@@ -165,15 +167,21 @@ def join(dm: Dimensigon, server: str, token: str, port: int = None, ssl: bool =
                 logger.error(f"Timeout of 20s reached while trying to contact to {server}.")
             except Exception as e:
                 logger.exception(f"Error trying to get dimensigon public key.")
-                resp = None
-            if resp.status_code != 200:
-                logger.error(f"Error trying to get dimensigon public key: {resp.status_code}, {resp.content}")
             else:
-                break
+                if resp.status_code != 200:
+                    if resp.status_code in (401, 422):
+                        logger.error(f"Error trying to get dimensigon public key: {resp.status_code}, {resp.content}")
+                        break
+                    else:
+                        logger.error(f"Error trying to get dimensigon public key: {resp.status_code}, {resp.content}")
+                else:
+                    break
             if i < times - 1:
                 d = int(random.random() * 25 * (i + 1))
                 logger.info(f"Retrying in {d} seconds.")
                 time.sleep(d)
+            else:
+                sys.exit(1)
 
         pub_key = rsa.PublicKey.load_pkcs1(resp.content)
 
@@ -184,7 +192,7 @@ def join(dm: Dimensigon, server: str, token: str, port: int = None, ssl: bool =
         data = s.to_json(add_gates=True)
         data = pack_msg2(data=data, pub_key=pub_key, priv_key=tmp_priv, symmetric_key=symmetric_key, add_key=True)
         data.update(my_pub_key=tmp_pub.save_pkcs1().decode('ascii'))
-        logger.info("Joining to dimension.")
+        logger.info("Joining to dimension...")
 
         resp = None
         times = 5
@@ -231,6 +239,28 @@ def join(dm: Dimensigon, server: str, token: str, port: int = None, ssl: bool =
                 fh.write(certfile_content)
                 del certfile_content
 
+            logger.info('Updating Catalog...')
+            reference_server_id = resp_data.pop('me')
+            # remove catalog
+            for c in Catalog.query.all():
+                db.session.delete(c)
+            try:
+                upgrade_catalog(resp_data['catalog']) # implicit commit
+            except Exception as e:
+                logger.exception(f"Unable to upgrade catalog.")
+                exit(1)
+            else:
+                logger.info('Catalog updated.')
+            # set reference server as a neighbour
+            reference_server = Server.query.get(reference_server_id)
+            if not reference_server:
+                db.session.rollback()
+                logger.info(f"Server id {reference_server_id} not found in catalog.")
+                exit(1)
+            Route(destination=reference_server, cost=0)
+            # update_route_table_cost(True)
+            Parameter.set("join_server", f'{reference_server.id}')
+
             resp = None
             times = 5
             for i in range(times):
@@ -258,29 +288,8 @@ def join(dm: Dimensigon, server: str, token: str, port: int = None, ssl: bool =
             if resp.ok:
                 logger.info('Joined to the dimension.')
             else:
-                logger.error("Unable to confirm join")
+                logger.error("Unable to confirm join.")
 
-            logger.info('Updating Catalog')
-            reference_server_id = resp_data.pop('me')
-            # remove catalog
-            for c in Catalog.query.all():
-                db.session.delete(c)
-            try:
-                upgrade_catalog(resp_data['catalog']) # implicit commit
-            except Exception as e:
-                logger.exception(f"Unable to upgrade catalog.")
-                exit(1)
-            else:
-                logger.info('Catalog updated.')
-            # set reference server as a neighbour
-            reference_server = Server.query.get(reference_server_id)
-            if not reference_server:
-                db.session.rollback()
-                logger.info(f"Server id {reference_server_id} not found in catalog.")
-                exit(1)
-            Route(destination=reference_server, cost=0)
-            # update_route_table_cost(True)
-            Parameter.set("join_server", f'{reference_server.id}')
             db.session.commit()
         else:
             logger.error(f"No dimension in response data.")
@@ -413,6 +422,12 @@ def get_arguments() -> argparse.Namespace:
         metavar="FILE",
         help="The Error log file to write to.",
     )
+    parser.add_argument(
+        "--logconfig-file",
+        metavar="FILE",
+        type=argparse.FileType('r'),
+        help="The log configuration in yaml format to load.",
+    )
     parser.add_argument(
         "--dm-refresh-interval",
         help="Period time in minutes to execute the routing and catalog refresh.",
@@ -438,8 +453,7 @@ def get_arguments() -> argparse.Namespace:
     join_parser = subparser.add_parser("join", help="Joins to the dimension.")
     join_parser.add_argument(
         "SERVER",
-        help="Reference Server which will allow to join the dimension. You must specify server name or IP and "
-             "port separated by colon. Ex: 10.10.10.10:80"
+        help="Reference Server which will allow to join the dimension. You must specify server name or IP"
     )
     join_parser.add_argument(
         "TOKEN",
@@ -511,6 +525,7 @@ class RuntimeConfig:
     daemon: bool = None
     accesslog: str = None
     errorlog: str = None
+    logconfig: dict = None
     flask: bool = None
     refresh_interval: int = None
     force_scan: bool = None
@@ -520,6 +535,7 @@ def main():
     args = get_arguments()
 
     from dimensigon import bootstrap
+
     dm = bootstrap.setup_dm(RuntimeConfig(config_dir=args.config_dir,
                                           debug=args.debug,
                                           pid_file=args.pid_file,
@@ -531,6 +547,8 @@ def main():
                                           daemon=args.daemon,
                                           accesslog=args.accesslog,
                                           errorlog=args.errorlog,
+                                          logconfig=yaml.load(args.logconfig_file,
+                                                              Loader=yaml.FullLoader) if args.logconfig_file else {},
                                           flask=args.flask,
                                           refresh_interval=args.dm_refresh_interval,
                                           force_scan=args.force_scan))
