@@ -60,5 +60,7 @@ DATEMARK_FORMAT = "%Y%m%d.%H%M%S.%f%z"
 
 SOFTWARE_REPO = 'software'
 DIMENSIGON_DIR = os.path.join(SOFTWARE_REPO, 'dimensigon')
-LOG_REPO = 'logs'
+LOG_FOLDER = 'logs'
+LOG_SENDER_REPO = 'logfed'
+
 
