@@ -1,4 +1,5 @@
 import datetime
+import logging
 import re
 import sys
 import threading
@@ -21,6 +22,8 @@ from dimensigon.web.errors import EntityNotFound, NoDataFound
 if t.TYPE_CHECKING:
     from dimensigon.domain.entities import Server
 
+logger = logging.getLogger(__name__)
+
 
 class BaseQueryJSON(BaseQuery):
     """SQLAlchemy :class:`~sqlalchemy.orm.query.Query` subclass with convenience methods for querying in a web application.
@@ -29,6 +32,12 @@ class BaseQueryJSON(BaseQuery):
     Override the query class for an individual model by subclassing this and setting :attr:`~Model.query_class`.
     """
 
+    def get(self, ident):
+        if ident:
+            return super().get(ident)
+        else:
+            return None
+
     def get_or_404(self, ident, description=None):
         """Like :meth:`get` but aborts with 404 if not found instead of returning ``None``."""
 
@@ -47,6 +56,7 @@ class BaseQueryJSON(BaseQuery):
             raise NoDataFound(self.column_descriptions[0]['name'])
         return rv
 
+
 class QueryWithSoftDelete(BaseQueryJSON):
     _with_deleted = False
 
@@ -77,7 +87,7 @@ class QueryWithSoftDelete(BaseQueryJSON):
         return obj if obj is None or self._with_deleted or not obj.deleted else None
 
 
-def filter_query(entity, filters, exclude: t.Container = None):
+def filter_query(entity, req_args: dict, exclude: t.Container = None):
     """Generates a sqlalchemy query object filtered by filters.
 
     entity: entity to filter
@@ -85,8 +95,12 @@ def filter_query(entity, filters, exclude: t.Container = None):
     exclude: columns to exclude on filter
 
     """
-    filters = [(re.search('^filter\[(\w+)\]$', k).group(1), v) for k, v in filters.items() if
-               k.startswith('filter[')]
+    filters = []
+    for k, v in req_args.items():
+        if k.startswith('filter['):
+            m = re.search('^filter\[(\w+)\]$', k)
+            if m:
+                filters.append((m.group(1), v))
     query = entity.query
     for k, v in filters:
         column = getattr(entity, k, None)
@@ -108,7 +122,6 @@ def check_param_in_uri(param):
     return param in request.args.getlist('params')
 
 
-
 def run_in_background(func: t.Callable, app=None, args=None, kwargs=None):
     args = args or ()
     kwargs = kwargs or {}
@@ -220,6 +233,5 @@ def session_scope():
         session.close()
 
 
-
 def get_auth_from_request():
-    return HTTPBearerAuth(request.headers['Authorization'].split()[1])
\ No newline at end of file
+    return HTTPBearerAuth(request.headers['Authorization'].split()[1])
